package com.jjt.risk.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.risk.domain.RiskAnalysis;
import com.jjt.risk.service.IRiskAnalysisService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 风险分析结果Controller
 *
 * @author jjt
 * @date 2024-09-12
 */
@Api(tags="风险分析结果")
@RestController
@RequestMapping("/risk/analysis")
public class RiskAnalysisController extends BaseController
{
    @Resource
    private IRiskAnalysisService riskAnalysisService;

    /**
     * 查询风险分析结果列表
     */
    @ApiOperation("查询风险分析结果列表")
    @PreAuthorize("@ss.hasPermi('risk:analysis:list')")
    @GetMapping("/list")
    public TableDataInfo list(RiskAnalysis riskAnalysis)
    {
        startPage();
        List<RiskAnalysis> list = riskAnalysisService.selectRiskAnalysisList(riskAnalysis);
        return getDataTable(list);
    }

    /**
     * 导出风险分析结果列表
     */
    @ApiOperation("导出风险分析结果列表")
    @PreAuthorize("@ss.hasPermi('risk:analysis:export')")
    @Log(title = "风险分析结果", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RiskAnalysis riskAnalysis)
    {
        List<RiskAnalysis> list = riskAnalysisService.selectRiskAnalysisList(riskAnalysis);
        ExcelUtil<RiskAnalysis> util = new ExcelUtil<RiskAnalysis>(RiskAnalysis.class);
        util.exportExcel(response, list, "风险分析结果数据");
    }

    /**
     * 获取风险分析结果详细信息
     */
    @ApiOperation("获取风险分析结果详细信息")
    @PreAuthorize("@ss.hasPermi('risk:analysis:query')")
    @GetMapping(value = "/{resultId}")
    public AjaxResult getInfo(@PathVariable("resultId") Long resultId)
    {
        return success(riskAnalysisService.selectRiskAnalysisByResultId(resultId));
    }

    /**
     * 新增风险分析结果
     */
    @ApiOperation("新增风险分析结果")
    @PreAuthorize("@ss.hasPermi('risk:analysis:add')")
    @Log(title = "风险分析结果", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RiskAnalysis riskAnalysis)
    {
        return toAjax(riskAnalysisService.insertRiskAnalysis(riskAnalysis));
    }

    /**
     * 修改风险分析结果
     */
    @ApiOperation("修改风险分析结果")
    @PreAuthorize("@ss.hasPermi('risk:analysis:edit')")
    @Log(title = "风险分析结果", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RiskAnalysis riskAnalysis)
    {
        return toAjax(riskAnalysisService.updateRiskAnalysis(riskAnalysis));
    }

    /**
     * 删除风险分析结果
     */
    @ApiOperation("删除风险分析结果")
    @PreAuthorize("@ss.hasPermi('risk:analysis:remove')")
    @Log(title = "风险分析结果", businessType = BusinessType.DELETE)
	@DeleteMapping("/{resultIds}")
    public AjaxResult remove(@PathVariable Long[] resultIds)
    {
        return toAjax(riskAnalysisService.deleteRiskAnalysisByResultIds(resultIds));
    }
}
