package com.jjt.risk.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.risk.domain.RiskModel;
import com.jjt.risk.service.IRiskModelService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 风险管理Controller
 *
 * @author jjt
 * @date 2024-09-12
 */
@Api(tags="风险管理")
@RestController
@RequestMapping("/risk/model")
public class RiskModelController extends BaseController
{
    @Resource
    private IRiskModelService riskModelService;

    /**
     * 查询风险管理列表
     */
    @ApiOperation("查询风险管理列表")
    @PreAuthorize("@ss.hasPermi('risk:model:list')")
    @GetMapping("/list")
    public TableDataInfo list(RiskModel riskModel)
    {
        startPage();
        List<RiskModel> list = riskModelService.selectRiskModelList(riskModel);
        return getDataTable(list);
    }

    /**
     * 导出风险管理列表
     */
    @ApiOperation("导出风险管理列表")
    @PreAuthorize("@ss.hasPermi('risk:model:export')")
    @Log(title = "风险管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RiskModel riskModel)
    {
        List<RiskModel> list = riskModelService.selectRiskModelList(riskModel);
        ExcelUtil<RiskModel> util = new ExcelUtil<RiskModel>(RiskModel.class);
        util.exportExcel(response, list, "风险管理数据");
    }

    /**
     * 获取风险管理详细信息
     */
    @ApiOperation("获取风险管理详细信息")
    @PreAuthorize("@ss.hasPermi('risk:model:query')")
    @GetMapping(value = "/{riskId}")
    public AjaxResult getInfo(@PathVariable("riskId") Long riskId)
    {
        return success(riskModelService.selectRiskModelByRiskId(riskId));
    }

    /**
     * 新增风险管理
     */
    @ApiOperation("新增风险管理")
    @PreAuthorize("@ss.hasPermi('risk:model:add')")
    @Log(title = "风险管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RiskModel riskModel)
    {
        return toAjax(riskModelService.insertRiskModel(riskModel));
    }

    /**
     * 修改风险管理
     */
    @ApiOperation("修改风险管理")
    @PreAuthorize("@ss.hasPermi('risk:model:edit')")
    @Log(title = "风险管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RiskModel riskModel)
    {
        return toAjax(riskModelService.updateRiskModel(riskModel));
    }

    /**
     * 删除风险管理
     */
    @ApiOperation("删除风险管理")
    @PreAuthorize("@ss.hasPermi('risk:model:remove')")
    @Log(title = "风险管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{riskIds}")
    public AjaxResult remove(@PathVariable Long[] riskIds)
    {
        return toAjax(riskModelService.deleteRiskModelByRiskIds(riskIds));
    }
}
